Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/nextcloud/nextcloudpi.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'ncp-web/activate/JS.js')
-rw-r--r--ncp-web/activate/JS.js6
1 files changed, 3 insertions, 3 deletions
diff --git a/ncp-web/activate/JS.js b/ncp-web/activate/JS.js
index a46936da..3432dbe1 100644
--- a/ncp-web/activate/JS.js
+++ b/ncp-web/activate/JS.js
@@ -1,5 +1,5 @@
///
// NextcloudPlus Web Panel javascript library
//
// Copyleft 2017 by Ignacio Nunez Hernanz <nacho _a_t_ ownyourbits _d_o_t_ com>
// GPL licensed (see end of file) * Use at your own risk!
@@ -52,7 +52,7 @@ function nc_admin_ok_cb( result )
if ( ret.ret == '0' ) {
launch_nc_passwd();
} else {
- $('#error-box').fill( "NextCloudPlus not yet initialized, trying again in a few seconds ..." );
+ $('#error-box').fill( "NextCloudPi not yet initialized, trying again in a few seconds ..." );
setTimeout( launch_activation, 10000 );
}
}
@@ -96,7 +96,7 @@ $(function()
input.selectionStart = input.selectionEnd;
} );
- // activate NextCloudPlus
+ // activate NextCloudPi
$( '#activate-ncp' ).on( 'click', function(e)
{
$( '#activate-ncp' ).hide();
@@ -1,5 +1,5 @@
///
-// NextcloudPlus Web Panel javascript library
+// NextCloudPi Web Panel javascript library
//
// Copyleft 2017 by Ignacio Nunez Hernanz <nacho _a_t_ ownyourbits _d_o_t_ com>